==> xrdp-0.6.1-x86_64-3_slonly.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.xrdp.new:
if [ -e etc/rc.d/rc.xrdp ]; then
  cp -a etc/rc.d/rc.xrdp etc/rc.d/rc.xrdp.new.incoming
  cat etc/rc.d/rc.xrdp.new > etc/rc.d/rc.xrdp.new.incoming
  mv etc/rc.d/rc.xrdp.new.incoming etc/rc.d/rc.xrdp.new
fi

config etc/rc.d/rc.xrdp.new
config etc/xrdp/xrdp-xinitrc.new
config etc/xrdp/rsakeys.ini.new
config etc/xrdp/sesman.ini.new
config etc/xrdp/xrdp.ini.new
config etc/xrdp/km-0407.ini.new
config etc/xrdp/km-0409.ini.new
config etc/xrdp/km-040c.ini.new
config etc/xrdp/km-0410.ini.new
config etc/xrdp/km-0419.ini.new
config etc/xrdp/km-041d.ini.new
( cd usr/lib64/xrdp ; rm -rf libxrdp.so.0 )
( cd usr/lib64/xrdp ; ln -sf libxrdp.so.0.0.0 libxrdp.so.0 )
( cd usr/lib64/xrdp ; rm -rf libxrdp.so )
( cd usr/lib64/xrdp ; ln -sf libxrdp.so.0.0.0 libxrdp.so )
( cd usr/lib64/xrdp ; rm -rf libmc.so )
( cd usr/lib64/xrdp ; ln -sf libmc.so.0.0.0 libmc.so )
( cd usr/lib64/xrdp ; rm -rf librdp.so )
( cd usr/lib64/xrdp ; ln -sf librdp.so.0.0.0 librdp.so )
( cd usr/lib64/xrdp ; rm -rf libscp.so )
( cd usr/lib64/xrdp ; ln -sf libscp.so.0.0.0 libscp.so )
( cd usr/lib64/xrdp ; rm -rf libcommon.so.0 )
( cd usr/lib64/xrdp ; ln -sf libcommon.so.0.0.0 libcommon.so.0 )
( cd usr/lib64/xrdp ; rm -rf libcommon.so )
( cd usr/lib64/xrdp ; ln -sf libcommon.so.0.0.0 libcommon.so )
( cd usr/lib64/xrdp ; rm -rf librdp.so.0 )
( cd usr/lib64/xrdp ; ln -sf librdp.so.0.0.0 librdp.so.0 )
( cd usr/lib64/xrdp ; rm -rf libxup.so.0 )
( cd usr/lib64/xrdp ; ln -sf libxup.so.0.0.0 libxup.so.0 )
( cd usr/lib64/xrdp ; rm -rf libxup.so )
( cd usr/lib64/xrdp ; ln -sf libxup.so.0.0.0 libxup.so )
( cd usr/lib64/xrdp ; rm -rf libvnc.so.0 )
( cd usr/lib64/xrdp ; ln -sf libvnc.so.0.0.0 libvnc.so.0 )
( cd usr/lib64/xrdp ; rm -rf libscp.so.0 )
( cd usr/lib64/xrdp ; ln -sf libscp.so.0.0.0 libscp.so.0 )
( cd usr/lib64/xrdp ; rm -rf libvnc.so )
( cd usr/lib64/xrdp ; ln -sf libvnc.so.0.0.0 libvnc.so )
( cd usr/lib64/xrdp ; rm -rf libmc.so.0 )
( cd usr/lib64/xrdp ; ln -sf libmc.so.0.0.0 libmc.so.0 )

==> xrdp-0.9.4-x86_64-1_slonly.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}

config etc/xrdp/xrdp-xinitrc.new
config etc/xrdp/rsakeys.ini.new
config etc/xrdp/sesman.ini.new
config etc/xrdp/xrdp.ini.new
preserve_perms etc/rc.d/rc.xrdp.new
( cd usr/lib64/xrdp ; rm -rf libxrdpapi.so.0 )
( cd usr/lib64/xrdp ; ln -sf libxrdpapi.so.0.0.0 libxrdpapi.so.0 )
( cd usr/lib64/xrdp ; rm -rf libscp.so.0 )
( cd usr/lib64/xrdp ; ln -sf libscp.so.0.0.0 libscp.so.0 )
( cd usr/lib64/xrdp ; rm -rf libxrdpapi.so )
( cd usr/lib64/xrdp ; ln -sf libxrdpapi.so.0.0.0 libxrdpapi.so )
( cd usr/lib64/xrdp ; rm -rf libxrdp.so )
( cd usr/lib64/xrdp ; ln -sf libxrdp.so.0.0.0 libxrdp.so )
( cd usr/lib64/xrdp ; rm -rf libcommon.so )
( cd usr/lib64/xrdp ; ln -sf libcommon.so.0.0.0 libcommon.so )
( cd usr/lib64/xrdp ; rm -rf libcommon.so.0 )
( cd usr/lib64/xrdp ; ln -sf libcommon.so.0.0.0 libcommon.so.0 )
( cd usr/lib64/xrdp ; rm -rf libscp.so )
( cd usr/lib64/xrdp ; ln -sf libscp.so.0.0.0 libscp.so )
( cd usr/lib64/xrdp ; rm -rf libxrdp.so.0 )
( cd usr/lib64/xrdp ; ln -sf libxrdp.so.0.0.0 libxrdp.so.0 )
